#!/bin/bash
#

source ${PRODUCTS}/setup
OS=`uname`
if [ ${OS} = "Darwin" ]
then
    flvr=`ups flavor -2`
else
    flvr=`ups flavor`
fi
g4dir=${PRODUCTS}/geant4/v4_9_4/${flvr}-gcc45

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

mkdir -p ${g4dir}
if [ ! -d ${g4dir} ]
then
   echo "ERROR: failed to create ${g4dir}"
   exit 1
fi

# declare and then setup geant4
echo "Declaring geant4 v4_9_4 for flavor ${flvr}"
if [ ${OS} = "Darwin" ]
then
   ups declare geant4 v4_9_4 -r geant4/v4_9_4 -2 -m geant4.table -q gcc45
   ups declare geant4 v4_9_4 -r geant4/v4_9_4 -2 -m geant4.table -q build-gcc45
else 
   ups declare geant4 v4_9_4 -r geant4/v4_9_4 -4 -m geant4.table -q gcc45
   ups declare geant4 v4_9_4 -r geant4/v4_9_4 -4 -m geant4.table -q build-gcc45
fi

# this will complain because the lib directory does not yet exist
setup geant4 v4_9_4  -q build-gcc45

gccver=`gcc --version | head -1 | cut -f3 -d" " | cut -f1-2 -d"."`
gccfullver=`gcc --version | head -1 | cut -f3 -d" "`
if [ ${gccver} = "4.5" ]
then
  echo " OK - gcc version is ${gccfullver}"
else
  echo "ERROR: wrong gcc version ${gccfullver}"
  exit 1
fi

if [ ! -d ${G4WORKDIR} ]
then
   echo "ERROR: cannot find geant4 directory ${G4WORKDIR}"
   exit 1
fi

if [ ! -d ${G4INSTALL} ]
then
   echo "ERROR: cannot find geant4 directory ${G4INSTALL,}"
   exit 1
fi

set -x 

cd ${G4INSTALL}/source
gmake clean
gmake
gmake includes

if [ ! -d ${G4LIB} ]
then
   echo "ERROR: failed to create ${G4LIB}"
   echo "       Something is very wrong"
   exit 1
fi

# this should not complain
echo "Finished building geant4 for flavor ${flvr}"
setup geant4 v4_9_4 -q gcc45
echo "G4LIB is ${G4LIB}"

exit 0
